@@ -55,7 +55,7 @@ class Word(unicode):
         '''Translate the word to another language using Google's
         Translate API.
 
-        New in `0.5.0`.
+        .. versionadded:: 0.5.0
         '''
         return self.translator.translate(self.string,
                                         from_lang=from_lang, to_lang=to)
@@ -63,7 +63,7 @@ class Word(unicode):
     def detect_language(self):
         '''Detect the word's language using Google's Translate API.
 
-        New in `0.5.0`.
+        .. versionadded:: 0.5.0
         '''
         return self.translator.detect(self.string)
 
@@ -235,7 +235,7 @@ class BaseBlob(ComparableMixin):
 
         :rtype: float
         '''
-        return PatternAnalyzer().analyze(str(self))[0]
+        return PatternAnalyzer().analyze(self.raw)[0]
 
     @cached_property
     def subjectivity(self):
@@ -244,7 +244,7 @@ class BaseBlob(ComparableMixin):
 
         :rtype: float
         '''
-        return PatternAnalyzer().analyze(str(self))[1]
+        return PatternAnalyzer().analyze(self.raw)[1]
 
     @cached_property
     def noun_phrases(self):
@@ -316,7 +316,7 @@ class BaseBlob(ComparableMixin):
         Language code reference:
             https://developers.google.com/translate/v2/using_rest#language-params
 
-        New in `0.5.0`.
+        .. versionadded:: 0.5.0.
 
         :param from_lang: Language to translate from.
         :param to: Language to translate to.
@@ -341,7 +341,7 @@ class BaseBlob(ComparableMixin):
         Language code reference:
             https://developers.google.com/translate/v2/using_rest#language-params
 
-        New in `0.5.0`.
+        .. versionadded:: 0.5.0
 
         :rtype: str
 
@@ -409,44 +409,44 @@ class BaseBlob(ComparableMixin):
         - `other`: a string or a text object
         '''
         if type(other) in string_types:
-            return TextBlob(str(self) + other)
+            return TextBlob(self.raw + other)
         elif isinstance(other, BaseBlob):
-            return TextBlob(str(self) + str(other))
+            return TextBlob(self.raw + other.raw)
         else:
             raise TypeError('Operands must be either strings or {0} objects'
                 .format(self.__class__.__name__))
 
     def __contains__(self, sub):
         '''Implements the `in` keyword like a Python string.'''
-        return sub in str(self)
+        return sub in self.raw
 
     def find(self, sub, start=0, end=sys.maxsize):
         '''Behaves like the built-in str.find() method. Returns an integer,
         the index of the first occurrence of the substring argument sub in the
         sub-string given by [start:end].
         '''
-        return str(self).find(sub, start, end)
+        return self.raw.find(sub, start, end)
 
     def rfind(self, sub, start=0, end=sys.maxsize):
         '''Behaves like the built-in str.rfind() method. Returns an integer,
         the index of he last (right-most) occurence of the substring argument
         sub in the sub-sequence given by [start:end].
         '''
-        return str(self).rfind(sub, start, end)
+        return self.raw.rfind(sub, start, end)
 
     def index(self, sub, start=0, end=sys.maxsize):
         '''Like blob.find() but raise ValueError when the substring
         is not found.
         '''
-        return str(self).index(sub, start, end)
+        return self.raw.index(sub, start, end)
 
     def startswith(self, prefix, start=0, end=sys.maxsize):
         """Returns True if the blob starts with the given prefix."""
-        return str(self).startswith(prefix, start, end)
+        return self.raw.startswith(prefix, start, end)
 
     def endswith(self, suffix, start=0, end=sys.maxsize):
         """Returns True if the blob ends with the given suffix."""
-        return str(self).endswith(suffix, start, end)
+        return self.raw.endswith(suffix, start, end)
 
     # PEP8 aliases
     starts_with = startswith
@@ -454,35 +454,35 @@ class BaseBlob(ComparableMixin):
 
     def title(self):
         """Returns a blob object with the text in title-case."""
-        return TextBlob(str(self).title())
+        return self.__class__(self.raw.title())
 
     def format(self, *args, **kwargs):
         """Perform a string formatting operation, like the built-in
         `str.format(*args, **kwargs)`. Returns a blob object.
         """
-        return TextBlob(str(self).format(*args, **kwargs))
+        return self.__class__(self.raw.format(*args, **kwargs))
 
     def split(self, sep=None, maxsplit=sys.maxsize):
         """Behaves like the built-in str.split() except returns a
         WordList.
         """
-        return WordList(str(self).split(sep, maxsplit))
+        return WordList(self.raw.split(sep, maxsplit))
 
     def strip(self, chars=None):
         """Behaves like the built-in str.strip([chars]) method. Returns
         an object with leading and trailing whitespace removed.
         """
-        return self.__class__(str(self).strip(chars))
+        return self.__class__(self.raw.strip(chars))
 
     def upper(self):
         """Like str.upper(), returns new object with all upper-cased characters.
         """
-        return self.__class__(str(self).upper())
+        return self.__class__(self.raw.upper())
 
     def lower(self):
         """Like str.lower(), returns new object with all lower-cased characters.
         """
-        return self.__class__(str(self).lower())
+        return self.__class__(self.raw.lower())
 
     def join(self, iterable):
         """Behaves like the built-in `str.join(iterable)` method, except
@@ -491,13 +491,13 @@ class BaseBlob(ComparableMixin):
         Returns a blob which is the concatenation of the strings or blobs
         in the iterable.
         """
-        return self.__class__(str(self).join(iterable))
+        return self.__class__(self.raw.join(iterable))
 
     def replace(self, old, new, count=sys.maxsize):
         """Return a new blob object with all the occurence of `old` replaced
         by `new`.
         """
-        return self.__class__(str(self).replace(old, new, count))
+        return self.__class__(self.raw.replace(old, new, count))
 
 
 class TextBlob(BaseBlob):
@@ -516,7 +516,7 @@ class TextBlob(BaseBlob):
     @cached_property
     def sentences(self):
         '''Return list of :class:`Sentence <Sentence>` objects.'''
-        return TextBlob.create_sentence_objects(self.raw)
+        return TextBlob._create_sentence_objects(self.raw)
 
     @cached_property
     def words(self):
@@ -528,7 +528,7 @@ class TextBlob(BaseBlob):
         # blob into sentences before tokenizing to words
         words = []
         for sent in self.sentences:
-            words.extend(WordTokenizer().tokenize(str(sent), include_punc=False))
+            words.extend(WordTokenizer().tokenize(sent.raw, include_punc=False))
         return WordList(words)
 
 
@@ -539,23 +539,30 @@ class TextBlob(BaseBlob):
 
     @property
     def serialized(self):
-        '''Returns a list of each sentences dict representation.'''
+        '''Returns a list of each sentence's dict representation.'''
         return [sentence.dict for sentence in self.sentences]
 
 
     def to_json(self, *args, **kwargs):
         '''Return a json representation (str) of this blob.
         Takes the same arguments as json.dumps.
+
+        .. versionadded:: 0.5.1
         '''
         return json.dumps(self.serialized, *args, **kwargs)
 
     @property
     def json(self):
-        '''The json representation of this blob.'''
+        '''The json representation of this blob.
+
+        .. versionchanged:: 0.5.1
+            Made ``json`` a property instead of a method to restore backwards
+            compatibility that was broken after version 0.4.0.
+        '''
         return self.to_json()
 
     @staticmethod
-    def create_sentence_objects(blob):
+    def _create_sentence_objects(blob):
         '''Returns a list of Sentence objects given
         a list of sentence strings. Attempts to handle sentences that
         have more than one punctuation mark at the end of the sentence.
@@ -568,7 +575,7 @@ class TextBlob(BaseBlob):
         for sent in sentences:
             # Compute the start and end indices of the sentence
             # within the blob
-            start_index = blob.index(str(sent), char_index)
+            start_index = blob.index(sent, char_index)
             char_index += len(sent)
             # Create a Sentence object and add it the the list
             end_index = start_index + len(sent)
