@@ -3,6 +3,7 @@
 
 from .packages import nltk
 from .utils import strip_punc
+from .exceptions import MissingCorpusException
 
 
 class BaseTokenizer(nltk.tokenize.api.TokenizerI):
@@ -58,7 +59,33 @@ class SentenceTokenizer(BaseTokenizer):
     Uses an unsupervised algorithm to build a model for abbreviation owrds,
     collocations, and words, collocations, and words, that start sentences,
     then uses that to find sentence boundaries.
+    Tweaked slightly to make it more robust to sentences with multiple
+    punctuation at the end, e.g. "OMG! I am so LOL!!!"
     '''
 
     def tokenize(self, text):
-        return nltk.tokenize.sent_tokenize(text)
+        ret = []
+        try:
+            sentences = nltk.tokenize.sent_tokenize(text)  # Initial tokenization
+        except LookupError as err:
+            print(err)
+            raise MissingCorpusException()
+        # If there's only one sentence or string of text
+        if len(sentences) <= 1:
+            return sentences  # return the 1-element list
+        else:
+            for i, sentence in enumerate(sentences):
+                # Sometimes the NLTK tokenizer misses some punctuation when
+                # there are multiple punctuations, e.g. with ellipses ("...")
+                # or multiple exclamation points ("!!!")
+                try:
+                    next_token = sentences[i + 1]
+                except IndexError:
+                    # Continue if the last token is a punctuation
+                    if len(sentence) <= 1:
+                        continue
+                # If the next token is 1 character, assume it's a punctuation
+                if len(next_token) == 1:
+                    sentence = "".join([sentence, next_token]) # append the extra punctuation
+                ret.append(sentence)
+        return ret
